@@ -5,7 +5,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of everyapp.bootstrap.
-# Copyright (C) 2010 Krys Lawrence
+# Copyright (C) 2010-2012 Krys Lawrence
 #
 # everyapp.bootstrap is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the Free
@@ -67,10 +67,13 @@ from os.path import exists
 
 #: File name (or path) for the default configuration file.
 #:
-#: .. NOTE:: During script generation, the original customization source has a
+#: .. NOTE::
+#:
+#:    During script generation, the original customization source has a
 #:   ``DEFAULT_CONFIG_FILE_NAME`` token (with surrounding ``$`` characters)
 #:   which is replaced with the relative path to the bootstrap configuration
 #:   file when it is included in the bootstrap script.
+#
 # Meta-Note: The above note is written in such a way as to make sense both in
 #            the original source module as well as in the generated bootstrap
 #            script. :)
@@ -102,21 +105,19 @@ def extend_parser(parser):
 
     :parameter optparse.OptionParser parser: The command-line parser to use.
 
-    .. SEEALSO:: |doc/BOOTSTRAP.PY.txt| for the full list of command-line
-       options, including the new and modified ones.
+    .. SEEALSO::
 
-    .. SEEALSO:: |doc/BOOTSTRAP.CFG.txt| for details on the configuration file
-       and overriding default option values.
+       |doc/BOOTSTRAP.PY.txt| for the full list of command-line options,
+       including the new and modified ones.
+
+    .. SEEALSO::
+
+       |doc/BOOTSTRAP.CFG.txt| for details on the configuration file and
+       overriding default option values.
 
     """
     parser.set_usage('%prog [OPTIONS] [CONFIG_FILE]')
     parser.remove_option('--no-site-packages')
-    parser.add_option(
-      '--global-site-packages',
-      dest='global_site_packages',
-      action='store_true',
-      help='Include access to the global site-packages dir in the virtual '
-        'environment.')
     parser.remove_option('--distribute')
     parser.add_option(
       '--setuptools',
@@ -261,13 +262,14 @@ def adjust_options(options, args):
     :type options: |optparse.Values|
     :parameter tuple args: Any positional arguments from the command-line.
 
-    .. SEEALSO:: |doc/BOOTSTRAP.PY.txt| for the full list of command-line
-       options, including the new and modified ones.
+    .. SEEALSO::
+
+       |doc/BOOTSTRAP.PY.txt| for the full list of command-line options,
+       including the new and modified ones.
 
     """
     home_dir = '.'
     args[:] = [home_dir]
-    options.no_site_packages = not options.global_site_packages
     options.use_distribute = not options.use_setuptools
     options.unzip_setuptools = not options.zip_setuptools
 
@@ -285,8 +287,10 @@ def after_install(options, home_dir):
     :parameter str home_dir: The home directory of the virtual environment.
       (This is always set to ``'.'``).
 
-    .. SEEALSO:: |doc/BOOTSTRAP.CFG.txt| for details on how to specify what
-       distributions to install and what commands to run.
+    .. SEEALSO::
+
+       |doc/BOOTSTRAP.CFG.txt| for details on how to specify what distributions
+       to install and what commands to run.
 
     """
     _install_requirements(options)
@@ -304,8 +308,10 @@ def _install_requirements(options):
     :parameter options: The parsed command-line options.
     :type options: |optparse.Values|
 
-    .. SEEALSO:: :func:`_pip_install` and :func:`_easy_install` for the
-       specific details on how those two installers are invoked.
+    .. SEEALSO::
+
+       :func:`_pip_install` and :func:`_easy_install` for the specific details
+       on how those two installers are invoked.
 
     """
     for section_name, section_data in _config.items():
@@ -346,14 +352,20 @@ def _pip_install(distribution_specs, options):
     :parameter options: The parsed command-line options.
     :type options: |optparse.Values|
 
-    .. SEEALSO:: |doc/BOOTSTRAP.PY.txt| for details on how to override the
-       default :program:`pip install` options from the command-line.
+    .. SEEALSO::
 
-    .. SEEALSO:: |doc/BOOTSTRAP.CFG.txt| for details on how to override the
-       default :program:`pip install` options from the configuration file.
+       |doc/BOOTSTRAP.PY.txt| for details on how to override the default
+       :program:`pip install` options from the command-line.
 
-    .. SEEALSO:: :func:`_convert_pep314_versions` for details on distribution
-       specifier formats.
+    .. SEEALSO::
+
+       |doc/BOOTSTRAP.CFG.txt| for details on how to override the default
+       :program:`pip install` options from the configuration file.
+
+    .. SEEALSO::
+
+       :func:`_convert_pep314_versions` for details on distribution specifier
+       formats.
 
     """
     installer_opts = 'install ' + options.pip_install_options
@@ -374,14 +386,20 @@ def _easy_install(distribution_specs, options):
     :parameter options: The parsed command-line options.
     :type options: |optparse.Values|
 
-    .. SEEALSO:: |doc/BOOTSTRAP.PY.txt| for details on how to override the
-       default :program:`easy_install` options from the command-line.
+    .. SEEALSO::
 
-    .. SEEALSO:: |doc/BOOTSTRAP.CFG.txt| for details on how to override the
-       default :program:`easy_install` options from the configuration file.
+       |doc/BOOTSTRAP.PY.txt| for details on how to override the default
+       :program:`easy_install` options from the command-line.
 
-    .. SEEALSO:: :func:`_convert_pep314_versions` for details on distribution
-       specifier formats.
+    .. SEEALSO::
+
+       |doc/BOOTSTRAP.CFG.txt| for details on how to override the default
+       :program:`easy_install` options from the configuration file.
+
+    .. SEEALSO::
+
+       :func:`_convert_pep314_versions` for details on distribution specifier
+       formats.
 
     """
     distribution_specs = _convert_pep314_versions(distribution_specs)
@@ -476,9 +494,10 @@ def _run_commands(options):
     :parameter options: The parsed command-line options.
     :type options: |optparse.Values|
 
-    .. NOTE:: The commands are run in a sub-process but are not run through a
-       shell (e.g. :command:`bash`).  This means shell features are not
-       available.
+    .. NOTE::
+
+       The commands are run in a sub-process but are not run through a shell
+       (e.g. :command:`bash`).  This means shell features are not available.
 
     """
     if 'commands' not in _config or not _config['commands']:
